pub struct Point {
pub position: Vec3,
pub direction: Vec3,
pub area: f32,
pub gravity: f32,
pub eclipse: Etype,
pub flux: f32,
}Expand description
Struct defining a point on the surface of a model grid (e.g. of a star or disc etc.)
A Point has a position, a direction which is the surface normal, an area,
a relative gravity, a vector of phase pairs defining when the point is eclipsed by
another model component, and a flux.
Fields
position: Vec3direction: Vec3area: f32gravity: f32eclipse: Etypeflux: f32Implementations