Module potential

Module potential 

Functions

drpot
drpot computes partial derivatives of Roche potential with respect to position at p for mass ratio q. \param q mass ratio = M2/M1 \param p position (units of separation)
drpot1
drpot computes partial derivatives of Roche potential with respect to position at p for mass ratio q. \param q mass ratio = M2/M1 \param p position (units of separation)
drpot2
drpot2 computes partial derivatives of asynchronous Roche potential with respect to position at p for mass ratio q, star 2. \param q mass ratio = M2/M1 \param spin ratio of spin to orbital frequency. \param p position (units of separation)
rpot
rpot computes the Roche potential at a given point. This is for the standard synchronised Roche geometry \param q mass ratio = M2/M1 \param p the point in question (units scaled by separation) \return the Roche potential.
rpot1
rpot1 computes the Roche potential at a given point allowing for non-synchronous rotation of the primary. \param q mass ratio = M2/M1 \paran spin ratio spin/orbital frequencies \param p the point in question (units scaled by separation) \return the Roche potential.
rpot2
rpot2 computes the Roche potential at a given point allowing for non-synchronous rotation of the secondary. \param q mass ratio = M2/M1 \paran spin ratio spin/orbital frequencies \param p the point in question (units scaled by separation) \return the Roche potential.
rpot_grad
rpot_val
rpot_val_grad