Module stream_physics
rust_
roche
0.1.2
Module stream_
physics
Module Items
Functions
In crate rust_
roche
rust_roche
Module
stream_
physics
Functions

rocacc
rocacc calculates and returns the acceleration (in the rotating frame) in a Roche potential of a particle of given position and velocity.
stradv
stradv advances a particle of given position and velocity until it reaches a specified radius. It then returns with updated position and velocity. It is up to the user not to request a value that cannot be reached.
strinit
strinit sets a particle just inside the L1 point with the correct velocity as given in Lubow and Shu.